California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 63 - MENTAL HEALTH SERVICES EXPANSION AND FUNDING. TAX ON INCOMES OVER $1 MILLION. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1270705 | NO PROP 63 COMMITTEE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1260771 | NO ON PROP. 63, CITIZENS FOR A HEALTHY CALIFORNIA | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1267628 | NO ON PROPOSITION 63; SPONSORED BY THE NATIONAL TAX LIMITATION COMMITTEE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1254533 | CAMPAIGN FOR MENTAL HEALTH - YESON63.ORG - COMMUNITY MENTAL HEALTH PROVIDERS, FAMILIES, AND CONSUMERS, AND OTHER SUPPORTERS OF INCREASED MENTAL HEALTH SERVICES FUNDING | SUPPORT